.. note::

    Ophyd async is included on a provisional basis until the v1.0 release and 
    may change API on minor release numbers before then

API
===

.. automodule:: ophyd_async

    ``ophyd_async``
    -----------------------------------

This is the internal API reference for ophyd_async

.. data:: ophyd_async.__version__
    :type: str

    Version number as calculated by https://github.com/pypa/setuptools_scm


.. autosummary::
    :toctree: ../generated
    :template: custom-module-template.rst
    :recursive:

    core
    epics
    panda